@@ -85,9 +85,9 @@ def get_option_parser():
     return parser
 
 
-def show_list_main() -> None:
+def show_list_main(stdout=sys.stdout) -> None:
     for basename in get_clock_basenames():
-        print(basename)
+        print(basename, file=stdout)
 
 
 def specified_time_main(opt, args) -> None:
